@@ -19,6 +19,8 @@ class TimestreamLoader(TimestreamReader):
         table_name: str = None,
         session: boto3.Session = None,
         current_time_ms: int = None,
+        max_batch_size: int = None,
+        min_common_dimensions: int = None,
         logger: logging.Logger = None
     ):
         assert database_name, 'Must specify a database_name'
@@ -26,14 +28,8 @@ class TimestreamLoader(TimestreamReader):
         super().__init__(session, current_time_ms, logger)
         self.__database_name = database_name
         self.__table_name = table_name
-
-    @property
-    def database_name(self) -> str:
-        return self.__database_name
-
-    @property
-    def table_name(self) -> str:
-        return self.__table_name
+        self.__max_batch_size = max_batch_size if max_batch_size else DEFAULT_MAX_BATCH_SIZE
+        self.__min_common_dimensions = min_common_dimensions if min_common_dimensions else DEFAULT_MIN_COMMON_DIMENSIONS
 
     def does_database_exist(
         self,
@@ -65,9 +61,7 @@ class TimestreamLoader(TimestreamReader):
         capture_time: datetime,
         source: str = None,
         upsert: bool = False,
-        ignore_parse_error: bool = True,
-        max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
+        ignore_parse_error: bool = True
     ) -> dict:
         '''
         Performs a Timestream load. Validates the input and parses the data into Timestream records.
@@ -79,8 +73,6 @@ class TimestreamLoader(TimestreamReader):
             source,
             upsert,
             ignore_parse_error,
-            max_batch_size,
-            min_common_dimensions,
             False
         ).to_dict()
 
@@ -90,9 +82,7 @@ class TimestreamLoader(TimestreamReader):
         capture_time: datetime,
         source: str = None,
         upsert: bool = False,
-        ignore_parse_error: bool = True,
-        max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS
+        ignore_parse_error: bool = True
     ) -> dict:
         '''
         Performs a dry run of a Timestream load, including validating the input values and parsing data
@@ -105,8 +95,6 @@ class TimestreamLoader(TimestreamReader):
             source,
             upsert,
             ignore_parse_error,
-            max_batch_size,
-            min_common_dimensions,
             True
         ).to_dict()
 
@@ -117,8 +105,6 @@ class TimestreamLoader(TimestreamReader):
         source: str = None,
         upsert: bool = False,
         ignore_parse_error: bool = True,
-        max_batch_size: int = DEFAULT_MAX_BATCH_SIZE,
-        min_common_dimensions: int = DEFAULT_MIN_COMMON_DIMENSIONS,
         preview: bool = False
     ) -> TimestreamLoadResult:
         self._logger.info(f'Loading data with {len(data)} elements')
@@ -129,14 +115,15 @@ class TimestreamLoader(TimestreamReader):
             return result
 
         # Batch the accepted records by common dimensions
+        self._logger.info('starting batching...')
         batches = batch_records(
             result.accepted_records,
-            max_batch_size=max_batch_size,
-            min_common_dimensions=min_common_dimensions
+            max_batch_size=self.__max_batch_size,
+            min_common_dimensions=self.__min_common_dimensions
         )
         assert isinstance(batches, list) and len(batches) > 0, 'Batches must be a non-empty list'
         assert all(len(b.records) > 0 for b in batches), "Not all batches have records (shouldn't be possible)"
-
+        self._logger.info('batching complete')
         # Write records in batches to Timestream
         result = TimestreamLoadResult()
         for b in batches:
